@@ -3,31 +3,27 @@ from BinPy.tools import *
 from nose.tools import with_setup, nottest
 
 
-def PowerSourceTest():
+def test_PowerSourceTest():
     POW = PowerSource()
     a = Connector()
 
     POW.connect(a)
-    print((a.state))
     if a.state != 1:
         assert False
 
     POW.disconnect(a)
-    print((a.state))
     if a.state is not None:
         assert False
 
 
-def GroundTest():
+def test_GroundTest():
     GND = Ground()
     a = Connector()
 
     GND.connect(a)
-    print((a.state))
     if a.state != 0:
         assert False
 
     GND.disconnect(a)
-    print((a.state))
     if a.state is not None:
         assert False
